@@ -1,10 +1,10 @@
 import re
 from typing import Generic, Optional, TypeVar
 
+import fastapi
 import pydantic
 import pydantic.generics
 import ujson
-import fastapi
 
 snake_regexp = re.compile(r'_([a-z])')
 
@@ -17,8 +17,8 @@ class Model(pydantic.BaseModel):
 
         @classmethod
         def alias_generator(cls, field: str):
-            if field == "id_":
-                return "id"
+            if field == 'id_':
+                return 'id'
             return re.sub(snake_regexp, lambda match: match[1].upper(), field)
 
 
@@ -29,6 +29,7 @@ class FrozenModel(Model):
 
 T = TypeVar('T', bound=Model)
 
+
 class Details(FrozenModel):
     last_id: Optional[int] = None
     total_pages: Optional[int] = None
@@ -40,10 +41,12 @@ class BaseResponse(pydantic.generics.GenericModel, Generic[T]):
     data: list[T]
     details: Optional[Details] = pydantic.Field(default_factory=Details)
 
+
 class Page(FrozenModel):
     last_id: int = fastapi.Query(0, ge=0)
     per_page: int = fastapi.Query(20, ge=5, le=100)
 
+
 class BaseError(Model):
     title: str
     path: str
