@@ -3,7 +3,6 @@ from typing import Union
 
 import fastapi
 import fastapi.responses
-from aiomysql import DatabaseError
 
 from souswift_core import dtos
 from souswift_core.exc import exceptions
@@ -59,7 +58,7 @@ def add_exception_handlers(
 ):
     for exception, handler in (
         (exceptions.APIError, _api_error_handler),
-        (DatabaseError, _database_error_handler),
+        (exceptions.DatabaseError, _database_error_handler),
     ):
         if exception in exclude:
             continue
