@@ -140,18 +140,31 @@ class FilterIterator(Filter):
 
 class DateFilter:
     def __init__(self, driver: Driver):
-        self.driver = driver
+        self._driver = driver
 
     @staticmethod
     def format(date_part: int):
         return str(date_part).zfill(2)
 
     def day(self, column: Column):
-        if self.driver is Driver.SQLITE:
+        if self._driver is Driver.SQLITE:
             return func.strftime('%d', column)
         return extract('DAY', column)
 
     def month(self, column: Column):
-        if self.driver is Driver.SQLITE:
+        if self._driver is Driver.SQLITE:
             return func.strftime('%m', column)
         return extract('MONTH', column)
+
+
+class JSONFilter:
+    def __init__(self, driver: Driver):
+        self._driver = driver
+
+    @property
+    def contains(self):
+        return True if self._driver is Driver.SQLITE else cp.JSONContains()
+
+    @property
+    def empty(self):
+        return True if self._driver is Driver.SQLITE else cp.EmptyJson()
